@@ -6,7 +6,8 @@ from httpkit.helper.cookie import set_cookie, delete_cookie
 from pipestack.ensure import ensure_method_marble as ensure_action
 from dreamweavertemplate.decorator import render_template
 from bn import HTMLFragment, AttributeDict
-from formbuild import Form
+from formbuild import TableForm
+from markupsafe import Markup
 from formconvert import multiDictToDict
 from nestedrecord import encode_error
 from recordconvert import toRecord
@@ -165,15 +166,14 @@ class IndexArea(BaseArea):
             )
 
     def on_view_form(self, marble, value=None, error=None, option=None):
-        form = Form(
+        form = TableForm(
             value=value,
             error=error,
             option=option,
         )
-        fragment = HTMLFragment()
         marble.url_parts['query'] = None
-        fragment.safe(form.start_with_layout(marble.url(area=marble.vars.area, action='login')))
-        fragment.safe(
+        result = Markup(
+            form.start_with_layout(marble.url(area=marble.vars.area, action='login')) + \
             form.field(
                 name='username', 
                 label=marble.config.username,
@@ -181,9 +181,7 @@ class IndexArea(BaseArea):
                 side=marble.config.side,
                 colon=marble.config.colon,
                 #required=True,
-            )
-        )
-        fragment.safe(
+            ) + \
             form.field(
                 name='password', 
                 label=marble.config.password,
@@ -193,8 +191,8 @@ class IndexArea(BaseArea):
                 #required=True,
             )
         )
-        actions = u'<br />'+form.submit(name='submit', value=marble.config.submit_value)
-        fragment.safe(form.action_bar(actions))
-        fragment.safe(form.end_with_layout(hidden_field_names=['referrer']))
-        return fragment.getvalue()
+        actions = Markup(u'<br />')+form.submit(name='submit', value=marble.config.submit_value)
+        result += form.action_bar(actions)
+        result += form.end_with_layout(hidden_field_names=['referrer'])
+        return result
 
